/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2017.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWCAMP_NAMESPACE_HPP__
#define __FWCAMP_NAMESPACE_HPP__

/**
 * @brief       All necessary for camp binding with simple types.
 */
namespace fwCamp
{
/**
 * @brief       Contains fwCamp::registry details
 */
namespace registry
{
} // namespace registry

/**
 * @brief       Contains fwCamp::factory utilities
 */
namespace factory
{
} // namespace factory

}  // namespace fwCamp

#endif //__FWCAMP_NAMESPACE_HPP__
